ModulatoryProjection
====================

.. _ModulatoryProjection_Subtypes:

.. container:: subclasses

    *Subclasses*

    .. toctree::
       :maxdepth: 1

       LearningProjection
       ControlProjection
       GatingProjection

.. automodule:: psyneulink.core.components.projections.modulatory.modulatoryprojection
   :members: ModulatoryProjection_Base
   :private-members:
   :exclude-members: Linear, random, Parameters
